==> haskell-hslua-repl-0.1.2-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-FYKaYP5o73NBAV8iPRe8dK
key:                  hslua-repl-0.1.2-FYKaYP5o73NBAV8iPRe8dK
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  2f68822edcc0a3d4b4c7ea72e4c9d438
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-FYKaYP5o73NBAV8iPRe8dK
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-4hgLjDnq8bkGMy9zvHPYf9
    isocline-1.0.9-IBnHwK5smnT23zzRSM2Fhz
    lua-2.3.3-Hr4HkkryhIbAiSCOIZ5AOr text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-repl-0.1.2-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-FZkxNj5ImtFEQKyH6PaO3M
key:                  hslua-repl-0.1.2-FZkxNj5ImtFEQKyH6PaO3M
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  1bf5700c946d82199de9ab99febbe896
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-FZkxNj5ImtFEQKyH6PaO3M
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-6Q4xINRm3kT5ZYua9ZktuN
    isocline-1.0.9-IBnHwK5smnT23zzRSM2Fhz
    lua-2.3.3-Je6OKJvpZDF5pXot01ljKL text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
